local assets =
{
    Asset("ANIM", "anim/feces.zip"),
    Asset("ANIM", "anim/swap_feces.zip"),
	Asset("ATLAS", "images/inventoryimages/feces.xml"),
	Asset("IMAGE", "images/inventoryimages/feces.tex"),
}

local prefabs =
{

    "feces_splash",
    "sleepbomb_burst",
    "sleepcloud",
    "reticule",
    "reticuleaoe",
    "reticuleaoeping",
}

local function OnHit(inst, attacker, target)

		local pt = inst:GetPosition()
		local ents = TheSim:FindEntities(pt.x,pt.y,pt.z, 5, {"_combat"}, {"ghost", "shadow", "hostile"}, nil)
		
		SpawnPrefab("feces_splash").Transform:SetPosition(inst.Transform:GetWorldPosition())
		inst.components.wateryprotection:SpreadProtection(inst)
		inst:Remove()
		
		for i,v in ipairs(ents) do
			if v.components.sanity ~= nil then
				v.components.sanity:DoDelta(-5)
			end
		end
		for i,v in ipairs(ents) do
			if v.components.health ~= nil then
				v.components.health:DoDelta(-2)
			end
		end
	
	
end

local function onequip(inst, owner) 
    owner.AnimState:OverrideSymbol("swap_object", "swap_feces", "swap_feces")
    owner.AnimState:Show("ARM_carry") 
    owner.AnimState:Hide("ARM_normal") 
end

local function onunequip(inst, owner) 
    owner.AnimState:Hide("ARM_carry") 
    owner.AnimState:Show("ARM_normal") 
end

local function onthrown(inst)
    inst:AddTag("NOCLICK")
    inst.persists = false

    inst.AnimState:PlayAnimation("spin_loop")

    inst.Physics:SetMass(1)
    inst.Physics:SetCapsule(0.2, 0.2)
    inst.Physics:SetFriction(0)
    inst.Physics:SetDamping(0)
    inst.Physics:SetCollisionGroup(COLLISION.CHARACTERS)
    inst.Physics:ClearCollisionMask()
    inst.Physics:CollidesWith(COLLISION.WORLD)
    inst.Physics:CollidesWith(COLLISION.OBSTACLES)
    inst.Physics:CollidesWith(COLLISION.ITEMS)
end

local function ReticuleTargetFn()
    local player = ThePlayer
    local ground = TheWorld.Map
    local pos = Vector3()
    --Attack range is 8, leave room for error
    --Min range was chosen to not hit yourself (2 is the hit range)
    for r = 6.5, 3.5, -.25 do
        pos.x, pos.y, pos.z = player.entity:LocalToWorldSpace(r, 0, 0)
        if ground:IsPassableAtPoint(pos:Get()) and not ground:IsGroundTargetBlocked(pos) then
            return pos
        end
    end
    return pos
end

local function fn()
    local inst = CreateEntity()

    inst.entity:AddTransform()
    inst.entity:AddAnimState()
    inst.entity:AddSoundEmitter()
    inst.entity:AddNetwork()

    MakeInventoryPhysics(inst)

    --projectile (from complexprojectile component) added to pristine state for optimization
    inst:AddTag("projectile")

    inst.AnimState:SetBank("feces")
    inst.AnimState:SetBuild("feces")
    inst.AnimState:PlayAnimation("idle")
    inst.AnimState:SetDeltaTimeMultiplier(.75)

    inst:AddComponent("reticule")
    inst.components.reticule.targetfn = ReticuleTargetFn
    inst.components.reticule.ease = true

    local advancedtargeting = TheNet:GetServerGameMode() == "lavaarena"
    if advancedtargeting then
        inst.components.reticule.reticuleprefab = "reticuleaoe"
        inst.components.reticule.pingprefab = "reticuleaoeping"
        inst.components.reticule.mouseenabled = true

        inst:AddTag("nopunch")
    end

    inst.entity:SetPristine()

    if not TheWorld.ismastersim then
        return inst
    end


    inst:AddComponent("wateryprotection")	
    inst.components.wateryprotection.extinguishheatpercent = (0)
    inst.components.wateryprotection.witherprotectiontime = (50)
    inst.components.wateryprotection.addwetness = (100)
    inst.components.wateryprotection.canuseontargets = true
	
	
	
    inst:AddComponent("locomotor")

    inst:AddComponent("complexprojectile")
    inst.components.complexprojectile:SetHorizontalSpeed(15)
    inst.components.complexprojectile:SetGravity(-35)
    inst.components.complexprojectile:SetLaunchOffset(Vector3(.25, 1, 0))
    inst.components.complexprojectile:SetOnLaunch(onthrown)
    inst.components.complexprojectile:SetOnHit(OnHit)

    if not advancedtargeting then
        inst:AddComponent("weapon")
        inst.components.weapon:SetDamage(0)
        inst.components.weapon:SetRange(8, 10)
    end

    inst:AddComponent("inspectable")

	    inst:AddComponent("inventoryitem")
	inst.components.inventoryitem.imagename = "feces"
	inst.components.inventoryitem.atlasname = "images/inventoryimages/feces.xml"
    
	inst:AddComponent("stackable")

    inst:AddComponent("equippable")
    inst.components.equippable:SetOnEquip(onequip)
    inst.components.equippable:SetOnUnequip(onunequip)
    inst.components.equippable.equipstack = true

    MakeHauntableLaunch(inst)

    return inst
end

return Prefab("common/inventory/feces", fn, assets, prefabs)
